pub struct Field {
pub wire: &'static str,
pub kind: K,
pub enums: &'static [&'static str],
pub min_len: Option<u64>,
pub min_val: Option<i64>,
pub list_min: Option<u64>,
pub elem_kind: K,
pub is_union: bool,
pub children: &'static [Field],
}Expand description
A @required output member (recursively for structures / list
elements), enough for the engine to synthesise a shape-valid value.
Fields
wire: &'static strkind: Kenums: &'static [&'static str]min_len: Option<u64>min_val: Option<i64>list_min: Option<u64>For a list member, its @length min (>=1 means at least one element).
elem_kind: KFor a list member, the element kind (children holds the
element’s required members when it is a structure).
is_union: boolWhether this member is a union (synthesise exactly one member).
children: &'static [Field]Required members of a structure member, the single first member of a union, or the required members of a list element structure.